@@ -24,7 +24,7 @@
 # import PyQt4 
 from PyQt4 import QtCore, QtGui
 import sys
-import osso
+# import osso
 # To allow os.popen ('<<Terminal command>>').read() commands
 import os
 
@@ -40,7 +40,7 @@ import gobject
 import gn_cellinfo
 #import gtk
 
-osso_c = osso.Context("healthcheck", "666", True)
+# osso_c = osso.Context("healthcheck", "666", True)
 
 #Threading imports!
 # from threading import Thread
@@ -474,65 +474,64 @@ class Ui_MainWindow(object):
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
     def Cellular(self):
-                import dbus
-		regstatus = gn_cellinfo.RegStatus()
-		signalstrength = gn_cellinfo.SignalStrength()
+        import dbus
+	regstatus = gn_cellinfo.RegStatus()
+	signalstrength = gn_cellinfo.SignalStrength()
 
-		if (regstatus[0] == 0): status = 'home'
-		elif (regstatus[0] == 1): status = 'roam'
-		elif (regstatus[0] == 2): status = 'roam_blink'
-		elif (regstatus[0] == 3): status = 'no serv.'
-		elif (regstatus[0] == 4): status = 'no serv. search'
-		elif (regstatus[0] == 5): status = 'no serv. no search'
-		elif (regstatus[0] == 6): status = 'no sim'
-		elif (regstatus[0] == 8): status = 'power off'
-		elif (regstatus[0] == 9): status = 'nsps'
-		elif (regstatus[0] == 10): status = 'nsps no cover.'
-		elif (regstatus[0] == 10): status = 'sim rejected'
-		else: status = 'unknown'
+	if (regstatus[0] == 0): status = 'home'
+        elif (regstatus[0] == 1): status = 'roam'
+        elif (regstatus[0] == 2): status = 'roam_blink'
+	elif (regstatus[0] == 3): status = 'no serv.'
+	elif (regstatus[0] == 4): status = 'no serv. search'
+	elif (regstatus[0] == 5): status = 'no serv. no search'
+	elif (regstatus[0] == 6): status = 'no sim'
+	elif (regstatus[0] == 8): status = 'power off'
+	elif (regstatus[0] == 9): status = 'nsps'
+	elif (regstatus[0] == 10): status = 'nsps no cover.'
+	elif (regstatus[0] == 10): status = 'sim rejected'
+        else: status = 'unknown'
 
-		if (regstatus[5] == 0): network_type = 'home'
-		elif (regstatus[5] == 1): network_type = 'preferred'
-		elif (regstatus[5] == 2): network_type = 'forbidden'
-		elif (regstatus[5] == 2): network_type = 'other'
-		else: network_type = 'no network'
+	if (regstatus[5] == 0): network_type = 'home'
+	elif (regstatus[5] == 1): network_type = 'preferred'
+	elif (regstatus[5] == 2): network_type = 'forbidden'
+	elif (regstatus[5] == 2): network_type = 'other'
+	else: network_type = 'no network'
+        services = ""
+        if (regstatus[6] & 0x02): services += 'CS '
+	if (regstatus[6] & 0x01): services += 'GPRS '
+	if (regstatus[6] & 0x04): services += 'EGPRS '
+	if (regstatus[6] & 0x08): services += 'HSDPA '
+	if (regstatus[6] & 0x10): services += 'HSUPA'
 
-		services = ""
-		if (regstatus[6] & 0x02): services += 'CS '
-		if (regstatus[6] & 0x01): services += 'GPRS '
-		if (regstatus[6] & 0x04): services += 'EGPRS '
-		if (regstatus[6] & 0x08): services += 'HSDPA '
-		if (regstatus[6] & 0x10): services += 'HSUPA'
-
-		fraction = 1.0 / 100 * signalstrength[0]
-		text = " - %d dBm" % signalstrength[1]
-                self.lbl_pSignal_Info.setText(text)
+	fraction = 1.0 / 100 * signalstrength[0]
+	text = " - %d dBm" % signalstrength[1]
+        self.lbl_pSignal_Info.setText(text)
 
 
-		#print "reg 1 %i" % regstatus[4]
-		#print "reg 3 %i" % regstatus[3]
-		#print "reg 1 %i" % regstatus[1]
-		cell_id = regstatus[2] & 65535
-		cell_rnc = regstatus[2] >> 16
+	#print "reg 1 %i" % regstatus[4]
+	#print "reg 3 %i" % regstatus[3]
+	#print "reg 1 %i" % regstatus[1]
+	cell_id = regstatus[2] & 65535
+	cell_rnc = regstatus[2] >> 16
 		
-		#if (cell_rnc): self.lbl_pRNC_Info.setText(cell_rnc)
-		#else: print " "
-		self.lbl_pRNC_Info.setText(status)
-		self.lbl_CellID_Info.setText(str(cell_id))
-		#print status
-		#print network_type
-		#print "regstatus %i" % regstatus[7]
-		self.lbl_pServices_Info.setText(services)
+	#if (cell_rnc): self.lbl_pRNC_Info.setText(cell_rnc)
+	#else: print " "
+	self.lbl_pRNC_Info.setText(status)
+	self.lbl_CellID_Info.setText(str(cell_id))
+	#print status
+	#print network_type
+	#print "regstatus %i" % regstatus[7]
+	self.lbl_pServices_Info.setText(services)
 
-		##dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei
-                #bus = dbus.SystemBus()
-                #dbus_object = bus.get_object('com.nokia.phone.SIM', '/com/nokia/phone/SIM/security')
-                #dbus_interface = dbus.Interface(dbus_object, 'Phone.Sim.Security')
-                #print "imei"
-                #ia = dbus_interface.get_imei()
-                #ib = ia[15:]
-                #ic = ib[:15]
-                #print ic
+	##dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei
+        #bus = dbus.SystemBus()
+        #dbus_object = bus.get_object('com.nokia.phone.SIM', '/com/nokia/phone/SIM/security')
+        #dbus_interface = dbus.Interface(dbus_object, 'Phone.Sim.Security')
+        #print "imei"
+        #ia = dbus_interface.get_imei()
+        #ib = ia[15:]
+        #ic = ib[:15]
+        #print ic
                 
 
 
